@@ -1,6 +1,8 @@
 import asyncio
 import functools
+import sys
 
+VERSION=sys.version_info
 
 # every coroutine
 async def pause(sleep, *args, **kwargs):
@@ -173,12 +175,28 @@ class TaskLoop:
         self._name = name
 
     def create(self):
-        task = self.loop.create_task(coromask(self.coro, self.coro_args,
-                                              self.coro_kwargs, self.fargs),
-                                     name=self.name)
-        task.add_done_callback(
-            functools.partial(self.renew, task, self.coro, self.fargs))
-        return task
+        if INFO.major==3 and INFO.minor>=8:
+            task = asyncio.create_task(
+                coromask(
+                    self.coro,
+                    self.coro_args,
+                    self.coro_kwargs,
+                    self.fargs),
+                name=self.name)
+             task.add_done_callback(
+                 functools.partial(self.renew, task, self.coro, self.fargs))
+             return task
+        if INFO.major==3 and INFO.minor==7:
+            task = asyncio.create_task(
+                coromask(
+                    self.coro,
+                    self.coro_args,
+                    self.coro_kwargs,
+                    self.fargs))
+             task.add_done_callback(
+                 functools.partial(self.renew, task, self.coro, self.fargs))
+             return task
+
 
     def renew(self, task, coro, fargs, *args, **kwargs):
         """
@@ -204,17 +222,31 @@ class TaskLoop:
                 elif self.control in {"START", "CONTINUE"}:
                     if self.control == 'CONTINUE':
                         coro = self.coro
-                    task = loop.create_task(coromask(coro, result_args,
-                                                     result_kwargs, fargs),
-                                            name=self.name)
+                    task = None
+                    if INFO.major==3 and INFO.minor>=8:
+                        task = loop.create_task(
+                            coromask(coro, result_args,
+                                     result_kwargs, fargs),
+                            name=self.name)
+                    if INFO.major==3 and INFO.minor>=7:
+                        task = loop.create_task(
+                            coromask(coro, result_args,
+                                     result_kwargs, fargs))
                     task.add_done_callback(
                         functools.partial(self.renew, task, coro, fargs))
                 elif self.control == "PAUSE":
                     pause_args = [self.time_pause]
                     pause_kwargs = {}
-                    task = loop.create_task(coromask(pause, pause_args,
-                                                     pause_kwargs, fargs),
-                                            name=self.name)
+                    task = None
+                    if INFO.major==3 and INFO.minor>=8:
+                        task = loop.create_task(
+                            coromask(pause, pause_args,
+                                     pause_kwargs, fargs),
+                            name=self.name)
+                    if INFO.major==3 and INFO.minor>=7:
+                        task = loop.create_task(
+                            coromask(pause, pause_args,
+                                     pause_kwargs, fargs))
                     task.add_done_callback(
                         functools.partial(self.renew, task, pause, fargs))
             except asyncio.IncompleteReadError as incomplete_read:
